# coding: utf-8

"""
    VeeRoute.LSS Clustering

    VeeRoute.LSS Clustering API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_clustering
from vrt_lss_clustering.models.routing_matrix import RoutingMatrix  # noqa: E501
from vrt_lss_clustering.rest import ApiException

class TestRoutingMatrix(unittest.TestCase):
    """RoutingMatrix unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RoutingMatrix
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_clustering.models.routing_matrix.RoutingMatrix()  # noqa: E501
        if include_optional :
            return RoutingMatrix(
                waypoints = [
                    vrt_lss_clustering.models.waypoint.Waypoint(
                        latitude = 55.692789, 
                        longitude = 37.554554, 
                        duration = 15, )
                    ], 
                distances = [
                    [
                        1500
                        ]
                    ], 
                durations = [
                    [
                        1500
                        ]
                    ]
            )
        else :
            return RoutingMatrix(
                waypoints = [
                    vrt_lss_clustering.models.waypoint.Waypoint(
                        latitude = 55.692789, 
                        longitude = 37.554554, 
                        duration = 15, )
                    ],
                distances = [
                    [
                        1500
                        ]
                    ],
                durations = [
                    [
                        1500
                        ]
                    ],
        )

    def testRoutingMatrix(self):
        """Test RoutingMatrix"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.LSS Clustering

    VeeRoute.LSS Clustering API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_lss_clustering.configuration import Configuration


class PlanInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status': 'PlanStatus',
        'result_version': 'int',
        'planning_time': 'int',
        'waiting_time': 'int'
    }

    attribute_map = {
        'status': 'status',
        'result_version': 'result_version',
        'planning_time': 'planning_time',
        'waiting_time': 'waiting_time'
    }

    def __init__(self, status=None, result_version=None, planning_time=None, waiting_time=None, local_vars_configuration=None):  # noqa: E501
        """PlanInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._status = None
        self._result_version = None
        self._planning_time = None
        self._waiting_time = None
        self.discriminator = None

        self.status = status
        if result_version is not None:
            self.result_version = result_version
        if planning_time is not None:
            self.planning_time = planning_time
        if waiting_time is not None:
            self.waiting_time = waiting_time

    @property
    def status(self):
        """Gets the status of this PlanInfo.  # noqa: E501


        :return: The status of this PlanInfo.  # noqa: E501
        :rtype: PlanStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PlanInfo.


        :param status: The status of this PlanInfo.  # noqa: E501
        :type: PlanStatus
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def result_version(self):
        """Gets the result_version of this PlanInfo.  # noqa: E501

        Planning result version.  # noqa: E501

        :return: The result_version of this PlanInfo.  # noqa: E501
        :rtype: int
        """
        return self._result_version

    @result_version.setter
    def result_version(self, result_version):
        """Sets the result_version of this PlanInfo.

        Planning result version.  # noqa: E501

        :param result_version: The result_version of this PlanInfo.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                result_version is not None and result_version > 1000000):  # noqa: E501
            raise ValueError("Invalid value for `result_version`, must be a value less than or equal to `1000000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                result_version is not None and result_version < 0):  # noqa: E501
            raise ValueError("Invalid value for `result_version`, must be a value greater than or equal to `0`")  # noqa: E501

        self._result_version = result_version

    @property
    def planning_time(self):
        """Gets the planning_time of this PlanInfo.  # noqa: E501

        Actual planning time, in minutes.  # noqa: E501

        :return: The planning_time of this PlanInfo.  # noqa: E501
        :rtype: int
        """
        return self._planning_time

    @planning_time.setter
    def planning_time(self, planning_time):
        """Sets the planning_time of this PlanInfo.

        Actual planning time, in minutes.  # noqa: E501

        :param planning_time: The planning_time of this PlanInfo.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                planning_time is not None and planning_time > 2880):  # noqa: E501
            raise ValueError("Invalid value for `planning_time`, must be a value less than or equal to `2880`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                planning_time is not None and planning_time < 0):  # noqa: E501
            raise ValueError("Invalid value for `planning_time`, must be a value greater than or equal to `0`")  # noqa: E501

        self._planning_time = planning_time

    @property
    def waiting_time(self):
        """Gets the waiting_time of this PlanInfo.  # noqa: E501

        Time to prepare for planning, in minutes.  # noqa: E501

        :return: The waiting_time of this PlanInfo.  # noqa: E501
        :rtype: int
        """
        return self._waiting_time

    @waiting_time.setter
    def waiting_time(self, waiting_time):
        """Sets the waiting_time of this PlanInfo.

        Time to prepare for planning, in minutes.  # noqa: E501

        :param waiting_time: The waiting_time of this PlanInfo.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                waiting_time is not None and waiting_time > 2880):  # noqa: E501
            raise ValueError("Invalid value for `waiting_time`, must be a value less than or equal to `2880`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                waiting_time is not None and waiting_time < 0):  # noqa: E501
            raise ValueError("Invalid value for `waiting_time`, must be a value greater than or equal to `0`")  # noqa: E501

        self._waiting_time = waiting_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlanInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PlanInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.LSS Clustering

    VeeRoute.LSS Clustering API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_clustering
from vrt_lss_clustering.models.cluster_settings import ClusterSettings  # noqa: E501
from vrt_lss_clustering.rest import ApiException

class TestClusterSettings(unittest.TestCase):
    """ClusterSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ClusterSettings
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_clustering.models.cluster_settings.ClusterSettings()  # noqa: E501
        if include_optional :
            return ClusterSettings(
                configuration = 'default', 
                calculation_time = 30, 
                result_ttl = 10, 
                transport_factor = [
                    vrt_lss_clustering.models.transport_factor.TransportFactor(
                        transport_type = 'CAR', 
                        speed = 2.5, )
                    ], 
                routing = [
                    vrt_lss_clustering.models.routing.Routing(
                        transport_type = 'CAR', 
                        matrix = {"waypoints":[{"latitude":59.9345,"longitude":30.1504},{"latitude":59.942383,"longitude":30.258951},{"latitude":59.9545,"longitude":30.2004},{"latitude":59.89527,"longitude":30.261747},{"latitude":59.9745,"longitude":30.5004}],"distances":[[0,5822,1820,14130,23304],[5936,0,4931,8365,17731],[1819,4853,0,13161,22335],[14859,9056,13854,0,21440],[21777,16306,20772,19290,0]],"durations":[[0,13,7,24,36],[13,0,9,13,25],[7,9,0,21,32],[26,14,22,0,30],[34,23,30,28,0]]}, 
                        traffic_jams = [
                            vrt_lss_clustering.models.traffic_factor.TrafficFactor(
                                time_window = vrt_lss_clustering.models.time_window.TimeWindow(
                                    from = '2020-10-21T09:30+03:00', 
                                    to = '2020-10-21T19:45Z', ), 
                                length_multiplier = 2, 
                                length_additive = 20, 
                                time_multiplier = 2, 
                                time_additive = 30, )
                            ], )
                    ], 
                assumptions = vrt_lss_clustering.models.cluster_assumptions.ClusterAssumptions(
                    traffic_jams = False, 
                    flight_distance = True, ), 
                precision = 2, 
                limits = vrt_lss_clustering.models.cluster_limits.ClusterLimits(
                    min_points = 3, 
                    max_points = 3, )
            )
        else :
            return ClusterSettings(
        )

    def testClusterSettings(self):
        """Test ClusterSettings"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.LSS Clustering

    VeeRoute.LSS Clustering API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import vrt_lss_clustering
from vrt_lss_clustering.api.validate_api import ValidateApi  # noqa: E501
from vrt_lss_clustering.rest import ApiException


class TestValidateApi(unittest.TestCase):
    """ValidateApi unit test stubs"""

    def setUp(self):
        self.api = vrt_lss_clustering.api.validate_api.ValidateApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_validate(self):
        """Test case for validate

        Data validation for clustering.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from vrt_lss_clustering.api.cluster_api import ClusterApi
from vrt_lss_clustering.api.system_api import SystemApi
from vrt_lss_clustering.api.validate_api import ValidateApi



# coding: utf-8

"""
    VeeRoute.LSS Clustering

    VeeRoute.LSS Clustering API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_lss_clustering.configuration import Configuration


class TransportFactor(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'transport_type': 'TransportType',
        'speed': 'float'
    }

    attribute_map = {
        'transport_type': 'transport_type',
        'speed': 'speed'
    }

    def __init__(self, transport_type=None, speed=None, local_vars_configuration=None):  # noqa: E501
        """TransportFactor - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._transport_type = None
        self._speed = None
        self.discriminator = None

        self.transport_type = transport_type
        self.speed = speed

    @property
    def transport_type(self):
        """Gets the transport_type of this TransportFactor.  # noqa: E501


        :return: The transport_type of this TransportFactor.  # noqa: E501
        :rtype: TransportType
        """
        return self._transport_type

    @transport_type.setter
    def transport_type(self, transport_type):
        """Sets the transport_type of this TransportFactor.


        :param transport_type: The transport_type of this TransportFactor.  # noqa: E501
        :type: TransportType
        """
        if self.local_vars_configuration.client_side_validation and transport_type is None:  # noqa: E501
            raise ValueError("Invalid value for `transport_type`, must not be `None`")  # noqa: E501

        self._transport_type = transport_type

    @property
    def speed(self):
        """Gets the speed of this TransportFactor.  # noqa: E501

        Average vehicle speed multiplier.  # noqa: E501

        :return: The speed of this TransportFactor.  # noqa: E501
        :rtype: float
        """
        return self._speed

    @speed.setter
    def speed(self, speed):
        """Sets the speed of this TransportFactor.

        Average vehicle speed multiplier.  # noqa: E501

        :param speed: The speed of this TransportFactor.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and speed is None:  # noqa: E501
            raise ValueError("Invalid value for `speed`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                speed is not None and speed > 1000):  # noqa: E501
            raise ValueError("Invalid value for `speed`, must be a value less than or equal to `1000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                speed is not None and speed < 0.1):  # noqa: E501
            raise ValueError("Invalid value for `speed`, must be a value greater than or equal to `0.1`")  # noqa: E501

        self._speed = speed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TransportFactor):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TransportFactor):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.LSS Clustering

    VeeRoute.LSS Clustering API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_clustering
from vrt_lss_clustering.models.cluster_result import ClusterResult  # noqa: E501
from vrt_lss_clustering.rest import ApiException

class TestClusterResult(unittest.TestCase):
    """ClusterResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ClusterResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_clustering.models.cluster_result.ClusterResult()  # noqa: E501
        if include_optional :
            return ClusterResult(
                tracedata = vrt_lss_clustering.models.trace_data.TraceData(
                    code = 'client_server_service_time_id', ), 
                clusters = [
                    vrt_lss_clustering.models.cluster.Cluster(
                        performer_key = 'performer01', 
                        points_keys = [
                            'point01'
                            ], 
                        representer_key = 'point01', )
                    ], 
                validations = [
                    vrt_lss_clustering.models.validation.Validation(
                        type = 'info', 
                        entity_key = 'ord0001', 
                        entity_type = 'order', 
                        info = 'bad time windows', )
                    ], 
                unclustered_points = [
                    vrt_lss_clustering.models.unclustered_point.UnclusteredPoint(
                        point = vrt_lss_clustering.models.cluster_point.ClusterPoint(
                            key = 'location01', 
                            location = vrt_lss_clustering.models.location.Location(
                                latitude = 55.692789, 
                                longitude = 37.554554, 
                                arrival_duration = 15, 
                                departure_duration = 5, ), 
                            duration = 30, ), 
                        reason = 'undefined', )
                    ], 
                progress = 50, 
                info = vrt_lss_clustering.models.plan_info.PlanInfo(
                    status = 'FINISHED_IN_TIME', 
                    result_version = 13, 
                    planning_time = 10, 
                    waiting_time = 5, )
            )
        else :
            return ClusterResult(
        )

    def testClusterResult(self):
        """Test ClusterResult"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.LSS Clustering

    VeeRoute.LSS Clustering API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_lss_clustering.configuration import Configuration


class ClusterSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'configuration': 'str',
        'calculation_time': 'int',
        'result_ttl': 'int',
        'transport_factor': 'list[TransportFactor]',
        'routing': 'list[Routing]',
        'assumptions': 'ClusterAssumptions',
        'precision': 'int',
        'limits': 'ClusterLimits'
    }

    attribute_map = {
        'configuration': 'configuration',
        'calculation_time': 'calculation_time',
        'result_ttl': 'result_ttl',
        'transport_factor': 'transport_factor',
        'routing': 'routing',
        'assumptions': 'assumptions',
        'precision': 'precision',
        'limits': 'limits'
    }

    def __init__(self, configuration='default', calculation_time=40, result_ttl=20, transport_factor=[], routing=[], assumptions=None, precision=3, limits=None, local_vars_configuration=None):  # noqa: E501
        """ClusterSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._configuration = None
        self._calculation_time = None
        self._result_ttl = None
        self._transport_factor = None
        self._routing = None
        self._assumptions = None
        self._precision = None
        self._limits = None
        self.discriminator = None

        if configuration is not None:
            self.configuration = configuration
        if calculation_time is not None:
            self.calculation_time = calculation_time
        if result_ttl is not None:
            self.result_ttl = result_ttl
        if transport_factor is not None:
            self.transport_factor = transport_factor
        if routing is not None:
            self.routing = routing
        if assumptions is not None:
            self.assumptions = assumptions
        if precision is not None:
            self.precision = precision
        if limits is not None:
            self.limits = limits

    @property
    def configuration(self):
        """Gets the configuration of this ClusterSettings.  # noqa: E501

        Clustering configuration name. The configuration determines the result goal and quality.   # noqa: E501

        :return: The configuration of this ClusterSettings.  # noqa: E501
        :rtype: str
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this ClusterSettings.

        Clustering configuration name. The configuration determines the result goal and quality.   # noqa: E501

        :param configuration: The configuration of this ClusterSettings.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                configuration is not None and len(configuration) > 1000):
            raise ValueError("Invalid value for `configuration`, length must be less than or equal to `1000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                configuration is not None and len(configuration) < 1):
            raise ValueError("Invalid value for `configuration`, length must be greater than or equal to `1`")  # noqa: E501

        self._configuration = configuration

    @property
    def calculation_time(self):
        """Gets the calculation_time of this ClusterSettings.  # noqa: E501

        Calculation time in minutes. The countdown starts from the moment when data is uploaded to the server and clustering starts.   # noqa: E501

        :return: The calculation_time of this ClusterSettings.  # noqa: E501
        :rtype: int
        """
        return self._calculation_time

    @calculation_time.setter
    def calculation_time(self, calculation_time):
        """Sets the calculation_time of this ClusterSettings.

        Calculation time in minutes. The countdown starts from the moment when data is uploaded to the server and clustering starts.   # noqa: E501

        :param calculation_time: The calculation_time of this ClusterSettings.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                calculation_time is not None and calculation_time > 2880):  # noqa: E501
            raise ValueError("Invalid value for `calculation_time`, must be a value less than or equal to `2880`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                calculation_time is not None and calculation_time < 1):  # noqa: E501
            raise ValueError("Invalid value for `calculation_time`, must be a value greater than or equal to `1`")  # noqa: E501

        self._calculation_time = calculation_time

    @property
    def result_ttl(self):
        """Gets the result_ttl of this ClusterSettings.  # noqa: E501

        Clustering result lifetime, in minutes. The countdown starts from the moment when clustering is completed.   # noqa: E501

        :return: The result_ttl of this ClusterSettings.  # noqa: E501
        :rtype: int
        """
        return self._result_ttl

    @result_ttl.setter
    def result_ttl(self, result_ttl):
        """Sets the result_ttl of this ClusterSettings.

        Clustering result lifetime, in minutes. The countdown starts from the moment when clustering is completed.   # noqa: E501

        :param result_ttl: The result_ttl of this ClusterSettings.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                result_ttl is not None and result_ttl > 14400):  # noqa: E501
            raise ValueError("Invalid value for `result_ttl`, must be a value less than or equal to `14400`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                result_ttl is not None and result_ttl < 1):  # noqa: E501
            raise ValueError("Invalid value for `result_ttl`, must be a value greater than or equal to `1`")  # noqa: E501

        self._result_ttl = result_ttl

    @property
    def transport_factor(self):
        """Gets the transport_factor of this ClusterSettings.  # noqa: E501

        Vehicle speed change coefficients.  # noqa: E501

        :return: The transport_factor of this ClusterSettings.  # noqa: E501
        :rtype: list[TransportFactor]
        """
        return self._transport_factor

    @transport_factor.setter
    def transport_factor(self, transport_factor):
        """Sets the transport_factor of this ClusterSettings.

        Vehicle speed change coefficients.  # noqa: E501

        :param transport_factor: The transport_factor of this ClusterSettings.  # noqa: E501
        :type: list[TransportFactor]
        """

        self._transport_factor = transport_factor

    @property
    def routing(self):
        """Gets the routing of this ClusterSettings.  # noqa: E501

        Time and distance matrices list for each vehicle type. By specifying an external routing matrix, the `flight_distance`, `traffic_jams`, `transport_factor` parameters are not taken into account.   # noqa: E501

        :return: The routing of this ClusterSettings.  # noqa: E501
        :rtype: list[Routing]
        """
        return self._routing

    @routing.setter
    def routing(self, routing):
        """Sets the routing of this ClusterSettings.

        Time and distance matrices list for each vehicle type. By specifying an external routing matrix, the `flight_distance`, `traffic_jams`, `transport_factor` parameters are not taken into account.   # noqa: E501

        :param routing: The routing of this ClusterSettings.  # noqa: E501
        :type: list[Routing]
        """

        self._routing = routing

    @property
    def assumptions(self):
        """Gets the assumptions of this ClusterSettings.  # noqa: E501


        :return: The assumptions of this ClusterSettings.  # noqa: E501
        :rtype: ClusterAssumptions
        """
        return self._assumptions

    @assumptions.setter
    def assumptions(self, assumptions):
        """Sets the assumptions of this ClusterSettings.


        :param assumptions: The assumptions of this ClusterSettings.  # noqa: E501
        :type: ClusterAssumptions
        """

        self._assumptions = assumptions

    @property
    def precision(self):
        """Gets the precision of this ClusterSettings.  # noqa: E501

        Specifies the calculation accuracy in the decimal point sequence number. By default, 3, i.e. accuracy equals 0.001.   # noqa: E501

        :return: The precision of this ClusterSettings.  # noqa: E501
        :rtype: int
        """
        return self._precision

    @precision.setter
    def precision(self, precision):
        """Sets the precision of this ClusterSettings.

        Specifies the calculation accuracy in the decimal point sequence number. By default, 3, i.e. accuracy equals 0.001.   # noqa: E501

        :param precision: The precision of this ClusterSettings.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                precision is not None and precision > 6):  # noqa: E501
            raise ValueError("Invalid value for `precision`, must be a value less than or equal to `6`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                precision is not None and precision < 0):  # noqa: E501
            raise ValueError("Invalid value for `precision`, must be a value greater than or equal to `0`")  # noqa: E501

        self._precision = precision

    @property
    def limits(self):
        """Gets the limits of this ClusterSettings.  # noqa: E501


        :return: The limits of this ClusterSettings.  # noqa: E501
        :rtype: ClusterLimits
        """
        return self._limits

    @limits.setter
    def limits(self, limits):
        """Sets the limits of this ClusterSettings.


        :param limits: The limits of this ClusterSettings.  # noqa: E501
        :type: ClusterLimits
        """

        self._limits = limits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClusterSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ClusterSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.LSS Clustering

    VeeRoute.LSS Clustering API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_lss_clustering.configuration import Configuration


class Performer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'key': 'str',
        'home_location': 'Location',
        'transport_type': 'TransportType',
        'cost_per_meter': 'float',
        'cost_per_minute': 'float',
        'limits': 'ClusterLimits'
    }

    attribute_map = {
        'key': 'key',
        'home_location': 'home_location',
        'transport_type': 'transport_type',
        'cost_per_meter': 'cost_per_meter',
        'cost_per_minute': 'cost_per_minute',
        'limits': 'limits'
    }

    def __init__(self, key=None, home_location=None, transport_type=None, cost_per_meter=0, cost_per_minute=0, limits=None, local_vars_configuration=None):  # noqa: E501
        """Performer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._key = None
        self._home_location = None
        self._transport_type = None
        self._cost_per_meter = None
        self._cost_per_minute = None
        self._limits = None
        self.discriminator = None

        self.key = key
        if home_location is not None:
            self.home_location = home_location
        self.transport_type = transport_type
        if cost_per_meter is not None:
            self.cost_per_meter = cost_per_meter
        if cost_per_minute is not None:
            self.cost_per_minute = cost_per_minute
        if limits is not None:
            self.limits = limits

    @property
    def key(self):
        """Gets the key of this Performer.  # noqa: E501

        Unique ID.  # noqa: E501

        :return: The key of this Performer.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this Performer.

        Unique ID.  # noqa: E501

        :param key: The key of this Performer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and key is None:  # noqa: E501
            raise ValueError("Invalid value for `key`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) > 1024):
            raise ValueError("Invalid value for `key`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) < 1):
            raise ValueError("Invalid value for `key`, length must be greater than or equal to `1`")  # noqa: E501

        self._key = key

    @property
    def home_location(self):
        """Gets the home_location of this Performer.  # noqa: E501


        :return: The home_location of this Performer.  # noqa: E501
        :rtype: Location
        """
        return self._home_location

    @home_location.setter
    def home_location(self, home_location):
        """Sets the home_location of this Performer.


        :param home_location: The home_location of this Performer.  # noqa: E501
        :type: Location
        """

        self._home_location = home_location

    @property
    def transport_type(self):
        """Gets the transport_type of this Performer.  # noqa: E501


        :return: The transport_type of this Performer.  # noqa: E501
        :rtype: TransportType
        """
        return self._transport_type

    @transport_type.setter
    def transport_type(self, transport_type):
        """Sets the transport_type of this Performer.


        :param transport_type: The transport_type of this Performer.  # noqa: E501
        :type: TransportType
        """
        if self.local_vars_configuration.client_side_validation and transport_type is None:  # noqa: E501
            raise ValueError("Invalid value for `transport_type`, must not be `None`")  # noqa: E501

        self._transport_type = transport_type

    @property
    def cost_per_meter(self):
        """Gets the cost_per_meter of this Performer.  # noqa: E501

        Cost per move per meter.  # noqa: E501

        :return: The cost_per_meter of this Performer.  # noqa: E501
        :rtype: float
        """
        return self._cost_per_meter

    @cost_per_meter.setter
    def cost_per_meter(self, cost_per_meter):
        """Sets the cost_per_meter of this Performer.

        Cost per move per meter.  # noqa: E501

        :param cost_per_meter: The cost_per_meter of this Performer.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                cost_per_meter is not None and cost_per_meter < 0):  # noqa: E501
            raise ValueError("Invalid value for `cost_per_meter`, must be a value greater than or equal to `0`")  # noqa: E501

        self._cost_per_meter = cost_per_meter

    @property
    def cost_per_minute(self):
        """Gets the cost_per_minute of this Performer.  # noqa: E501

        Cost per minute.  # noqa: E501

        :return: The cost_per_minute of this Performer.  # noqa: E501
        :rtype: float
        """
        return self._cost_per_minute

    @cost_per_minute.setter
    def cost_per_minute(self, cost_per_minute):
        """Sets the cost_per_minute of this Performer.

        Cost per minute.  # noqa: E501

        :param cost_per_minute: The cost_per_minute of this Performer.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                cost_per_minute is not None and cost_per_minute < 0):  # noqa: E501
            raise ValueError("Invalid value for `cost_per_minute`, must be a value greater than or equal to `0`")  # noqa: E501

        self._cost_per_minute = cost_per_minute

    @property
    def limits(self):
        """Gets the limits of this Performer.  # noqa: E501


        :return: The limits of this Performer.  # noqa: E501
        :rtype: ClusterLimits
        """
        return self._limits

    @limits.setter
    def limits(self, limits):
        """Sets the limits of this Performer.


        :param limits: The limits of this Performer.  # noqa: E501
        :type: ClusterLimits
        """

        self._limits = limits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Performer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Performer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.LSS Clustering

    VeeRoute.LSS Clustering API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_lss_clustering.configuration import Configuration


class TrafficFactor(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'time_window': 'TimeWindow',
        'length_multiplier': 'float',
        'length_additive': 'float',
        'time_multiplier': 'float',
        'time_additive': 'float'
    }

    attribute_map = {
        'time_window': 'time_window',
        'length_multiplier': 'length_multiplier',
        'length_additive': 'length_additive',
        'time_multiplier': 'time_multiplier',
        'time_additive': 'time_additive'
    }

    def __init__(self, time_window=None, length_multiplier=1, length_additive=0, time_multiplier=1, time_additive=0, local_vars_configuration=None):  # noqa: E501
        """TrafficFactor - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._time_window = None
        self._length_multiplier = None
        self._length_additive = None
        self._time_multiplier = None
        self._time_additive = None
        self.discriminator = None

        self.time_window = time_window
        if length_multiplier is not None:
            self.length_multiplier = length_multiplier
        if length_additive is not None:
            self.length_additive = length_additive
        if time_multiplier is not None:
            self.time_multiplier = time_multiplier
        if time_additive is not None:
            self.time_additive = time_additive

    @property
    def time_window(self):
        """Gets the time_window of this TrafficFactor.  # noqa: E501


        :return: The time_window of this TrafficFactor.  # noqa: E501
        :rtype: TimeWindow
        """
        return self._time_window

    @time_window.setter
    def time_window(self, time_window):
        """Sets the time_window of this TrafficFactor.


        :param time_window: The time_window of this TrafficFactor.  # noqa: E501
        :type: TimeWindow
        """
        if self.local_vars_configuration.client_side_validation and time_window is None:  # noqa: E501
            raise ValueError("Invalid value for `time_window`, must not be `None`")  # noqa: E501

        self._time_window = time_window

    @property
    def length_multiplier(self):
        """Gets the length_multiplier of this TrafficFactor.  # noqa: E501

        Distance factor.  # noqa: E501

        :return: The length_multiplier of this TrafficFactor.  # noqa: E501
        :rtype: float
        """
        return self._length_multiplier

    @length_multiplier.setter
    def length_multiplier(self, length_multiplier):
        """Sets the length_multiplier of this TrafficFactor.

        Distance factor.  # noqa: E501

        :param length_multiplier: The length_multiplier of this TrafficFactor.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                length_multiplier is not None and length_multiplier > 100):  # noqa: E501
            raise ValueError("Invalid value for `length_multiplier`, must be a value less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                length_multiplier is not None and length_multiplier < 0):  # noqa: E501
            raise ValueError("Invalid value for `length_multiplier`, must be a value greater than or equal to `0`")  # noqa: E501

        self._length_multiplier = length_multiplier

    @property
    def length_additive(self):
        """Gets the length_additive of this TrafficFactor.  # noqa: E501

        Increasing the distance by this number, in meters.  # noqa: E501

        :return: The length_additive of this TrafficFactor.  # noqa: E501
        :rtype: float
        """
        return self._length_additive

    @length_additive.setter
    def length_additive(self, length_additive):
        """Sets the length_additive of this TrafficFactor.

        Increasing the distance by this number, in meters.  # noqa: E501

        :param length_additive: The length_additive of this TrafficFactor.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                length_additive is not None and length_additive > 100000):  # noqa: E501
            raise ValueError("Invalid value for `length_additive`, must be a value less than or equal to `100000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                length_additive is not None and length_additive < -100000):  # noqa: E501
            raise ValueError("Invalid value for `length_additive`, must be a value greater than or equal to `-100000`")  # noqa: E501

        self._length_additive = length_additive

    @property
    def time_multiplier(self):
        """Gets the time_multiplier of this TrafficFactor.  # noqa: E501

        Time factor.  # noqa: E501

        :return: The time_multiplier of this TrafficFactor.  # noqa: E501
        :rtype: float
        """
        return self._time_multiplier

    @time_multiplier.setter
    def time_multiplier(self, time_multiplier):
        """Sets the time_multiplier of this TrafficFactor.

        Time factor.  # noqa: E501

        :param time_multiplier: The time_multiplier of this TrafficFactor.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                time_multiplier is not None and time_multiplier > 100):  # noqa: E501
            raise ValueError("Invalid value for `time_multiplier`, must be a value less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                time_multiplier is not None and time_multiplier < 0):  # noqa: E501
            raise ValueError("Invalid value for `time_multiplier`, must be a value greater than or equal to `0`")  # noqa: E501

        self._time_multiplier = time_multiplier

    @property
    def time_additive(self):
        """Gets the time_additive of this TrafficFactor.  # noqa: E501

        Increasing the time by this number, in meters.  # noqa: E501

        :return: The time_additive of this TrafficFactor.  # noqa: E501
        :rtype: float
        """
        return self._time_additive

    @time_additive.setter
    def time_additive(self, time_additive):
        """Sets the time_additive of this TrafficFactor.

        Increasing the time by this number, in meters.  # noqa: E501

        :param time_additive: The time_additive of this TrafficFactor.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                time_additive is not None and time_additive > 1440):  # noqa: E501
            raise ValueError("Invalid value for `time_additive`, must be a value less than or equal to `1440`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                time_additive is not None and time_additive < -1440):  # noqa: E501
            raise ValueError("Invalid value for `time_additive`, must be a value greater than or equal to `-1440`")  # noqa: E501

        self._time_additive = time_additive

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TrafficFactor):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TrafficFactor):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    VeeRoute.LSS Clustering

    VeeRoute.LSS Clustering API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from vrt_lss_clustering.models.calculation_detail import CalculationDetail
from vrt_lss_clustering.models.check_result import CheckResult
from vrt_lss_clustering.models.cluster import Cluster
from vrt_lss_clustering.models.cluster_assumptions import ClusterAssumptions
from vrt_lss_clustering.models.cluster_limits import ClusterLimits
from vrt_lss_clustering.models.cluster_point import ClusterPoint
from vrt_lss_clustering.models.cluster_result import ClusterResult
from vrt_lss_clustering.models.cluster_settings import ClusterSettings
from vrt_lss_clustering.models.cluster_task import ClusterTask
from vrt_lss_clustering.models.inline_response400 import InlineResponse400
from vrt_lss_clustering.models.inline_response401 import InlineResponse401
from vrt_lss_clustering.models.inline_response403 import InlineResponse403
from vrt_lss_clustering.models.inline_response404 import InlineResponse404
from vrt_lss_clustering.models.inline_response415 import InlineResponse415
from vrt_lss_clustering.models.inline_response429 import InlineResponse429
from vrt_lss_clustering.models.inline_response500 import InlineResponse500
from vrt_lss_clustering.models.inline_response501 import InlineResponse501
from vrt_lss_clustering.models.inline_response502 import InlineResponse502
from vrt_lss_clustering.models.inline_response503 import InlineResponse503
from vrt_lss_clustering.models.inline_response504 import InlineResponse504
from vrt_lss_clustering.models.inline_response_default import InlineResponseDefault
from vrt_lss_clustering.models.location import Location
from vrt_lss_clustering.models.performer import Performer
from vrt_lss_clustering.models.plan_id import PlanId
from vrt_lss_clustering.models.plan_info import PlanInfo
from vrt_lss_clustering.models.plan_status import PlanStatus
from vrt_lss_clustering.models.routing import Routing
from vrt_lss_clustering.models.routing_matrix import RoutingMatrix
from vrt_lss_clustering.models.time_window import TimeWindow
from vrt_lss_clustering.models.trace_data import TraceData
from vrt_lss_clustering.models.traffic_factor import TrafficFactor
from vrt_lss_clustering.models.transport_factor import TransportFactor
from vrt_lss_clustering.models.transport_type import TransportType
from vrt_lss_clustering.models.unclustered_point import UnclusteredPoint
from vrt_lss_clustering.models.validate_result import ValidateResult
from vrt_lss_clustering.models.validation import Validation
from vrt_lss_clustering.models.version_result import VersionResult
from vrt_lss_clustering.models.waypoint import Waypoint
